@@ -1,6 +1,6 @@
 package CHI::Memoize;
 BEGIN {
-  $CHI::Memoize::VERSION = '0.02';
+  $CHI::Memoize::VERSION = '0.03';
 }
 use Carp;
 use CHI;
@@ -52,11 +52,12 @@ sub memoize {
           ? ( ( ref($passed_key) eq 'CODE' ) ? $passed_key->(@_) : ($passed_key) )
           : @_;
         if ( @key_parts == 1 && ( $key_parts[0] || 0 ) eq NO_MEMOIZE ) {
-            return $func_ref->();
+            return $func_ref->(@_);
         }
         else {
             my $key = [ $prefix, $wantarray, @key_parts ];
-            return $cache->compute( $key, {%compute_options}, $func_ref );
+            my $args = \@_;
+            return $cache->compute( $key, {%compute_options}, sub { $func_ref->(@$args) } );
         }
     };
     $memoized{$func_id} = CHI::Memoize::Info->new(
@@ -120,7 +121,7 @@ CHI::Memoize - Make functions faster with memoization, via CHI
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -375,6 +376,16 @@ the costs of the function itself.
 
 =back
 
+=head1 KNOWN BUGS
+
+=over
+
+=item *
+
+Memoizing a function will affect its call stack and its prototype.
+
+=back
+
 =head1 RELATED MODULES
 
 A number of modules address a subset of the problems addressed by this module,
